==> applet-service-1.0.2-20190125.034424-20-sources.jar: com/bizvane/appletservice/models/po/AppletVipPrivilegePO.java <==
package com.bizvane.appletservice.models.po;

import java.util.Date;

public class AppletVipPrivilegePO {

	/**
	 * 只读. 小程序会员卡特权表id. applet_vip_privilege_id
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "小程序会员卡特权表id", name = "appletVipPrivilegeId", required = false, example = "")
	private Long appletVipPrivilegeId;
	/**
	 * 只读. 小程序会员卡id. applet_vip_card_id
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "小程序会员卡等级 id", name = "appletVipCardId", required = false, example = "")
	private Long appletVipCardId;
	/**
	 * 只读. 特权logo. privilege_logo
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "特权logo", name = "privilegeLogo", required = false, example = "")
	private String privilegeLogo;
	/**
	 * 只读. 特权名称. privilege_name
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "特权名称", name = "privilegeName", required = false, example = "")
	private String privilegeName;
	/**
	 * 只读. 特权说明. privilege_explain
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "特权说明", name = "privilegeExplain", required = false, example = "")
	private String privilegeExplain;
	/**
	 * 只读. 创建人id. create_user_id
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. 创建人名. create_user_name
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人名", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. 创建时间. create_date
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建时间", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. 修改人id. modified_user_id
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
	private Long modifiedUserId;
	/**
	 * 只读. 修改人名. modified_user_name
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人名", name = "modifiedUserName", required = false, example = "")
	private String modifiedUserName;
	/**
	 * 只读. 修改时间. modified_date
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改时间", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. 数据有效性：1=有效；0=无效. valid
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "数据有效性：1=有效；0=无效", name = "valid", required = false, example = "")
	private Boolean valid;

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public Long getAppletVipPrivilegeId() {
		return appletVipPrivilegeId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setAppletVipPrivilegeId(Long appletVipPrivilegeId) {
		this.appletVipPrivilegeId = appletVipPrivilegeId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public Long getAppletVipCardId() {
		return appletVipCardId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setAppletVipCardId(Long appletVipCardId) {
		this.appletVipCardId = appletVipCardId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public String getPrivilegeLogo() {
		return privilegeLogo;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setPrivilegeLogo(String privilegeLogo) {
		this.privilegeLogo = privilegeLogo == null ? null : privilegeLogo.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public String getPrivilegeName() {
		return privilegeName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setPrivilegeName(String privilegeName) {
		this.privilegeName = privilegeName == null ? null : privilegeName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public String getPrivilegeExplain() {
		return privilegeExplain;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setPrivilegeExplain(String privilegeExplain) {
		this.privilegeExplain = privilegeExplain == null ? null : privilegeExplain.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public String getModifiedUserName() {
		return modifiedUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}
}

==> applet-service-2.0.2-20211018.024013-14-sources.jar: com/bizvane/appletservice/models/po/AppletVipPrivilegePO.java <==
package com.bizvane.appletservice.models.po;

import com.alibaba.fastjson.JSONObject;

import java.util.Date;

public class AppletVipPrivilegePO {

	/**
	 * 只读. 小程序会员卡特权表id. applet_vip_privilege_id
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "小程序会员卡特权表id", name = "appletVipPrivilegeId", required = false, example = "")
	private Long appletVipPrivilegeId;
	/**
	 * 只读. 小程序会员卡id. applet_vip_card_id
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "小程序会员卡等级 id", name = "appletVipCardId", required = false, example = "")
	private Long appletVipCardId;
	/**
	 * 只读. 特权logo. privilege_logo
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "特权logo", name = "privilegeLogo", required = false, example = "")
	private String privilegeLogo;
	/**
	 * 只读. 特权名称. privilege_name
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "特权名称", name = "privilegeName", required = false, example = "")
	private String privilegeName;
	/**
	 * 只读. 特权说明. privilege_explain
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "特权说明", name = "privilegeExplain", required = false, example = "")
	private String privilegeExplain;
	/**
	 * 只读. 创建人id. create_user_id
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. 创建人名. create_user_name
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人名", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. 创建时间. create_date
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建时间", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. 修改人id. modified_user_id
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
	private Long modifiedUserId;
	/**
	 * 只读. 修改人名. modified_user_name
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人名", name = "modifiedUserName", required = false, example = "")
	private String modifiedUserName;
	/**
	 * 只读. 修改时间. modified_date
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改时间", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. 数据有效性：1=有效；0=无效. valid
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	@io.swagger.annotations.ApiModelProperty(value = "数据有效性：1=有效；0=无效", name = "valid", required = false, example = "")
	private Boolean valid;

    @io.swagger.annotations.ApiModelProperty(value = "特权权益", name = "privilegeEquity", required = false, example = "")
    private String privilegeEquity;

    @io.swagger.annotations.ApiModelProperty(value = "是否跳转 0不跳转 1跳转", name = "whetherJump", required = false, example = "")
    private Boolean whetherJump;

    @io.swagger.annotations.ApiModelProperty(value = "跳转配置信息", name = "jumpInfo", required = false, example = "")
    private String jumpInfo;

    @io.swagger.annotations.ApiModelProperty(value = "跳转配置信息Json", name = "jumpInfo", required = false, example = "生产数据库版本5.6,不支持json格式存储,格式需要转换")
    private JSONObject jumpInfoJson;

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public Long getAppletVipPrivilegeId() {
		return appletVipPrivilegeId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setAppletVipPrivilegeId(Long appletVipPrivilegeId) {
		this.appletVipPrivilegeId = appletVipPrivilegeId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public Long getAppletVipCardId() {
		return appletVipCardId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setAppletVipCardId(Long appletVipCardId) {
		this.appletVipCardId = appletVipCardId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public String getPrivilegeLogo() {
		return privilegeLogo;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setPrivilegeLogo(String privilegeLogo) {
		this.privilegeLogo = privilegeLogo == null ? null : privilegeLogo.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public String getPrivilegeName() {
		return privilegeName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setPrivilegeName(String privilegeName) {
		this.privilegeName = privilegeName == null ? null : privilegeName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public String getPrivilegeExplain() {
		return privilegeExplain;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setPrivilegeExplain(String privilegeExplain) {
		this.privilegeExplain = privilegeExplain == null ? null : privilegeExplain.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public String getModifiedUserName() {
		return modifiedUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2018-08-07 15:36:32
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}

    public String getPrivilegeEquity() {
        return privilegeEquity;
    }

    public void setPrivilegeEquity(String privilegeEquity) {
        this.privilegeEquity = privilegeEquity;
    }

    public Boolean getWhetherJump() {
        return whetherJump;
    }

    public void setWhetherJump(Boolean whetherJump) {
        this.whetherJump = whetherJump;
    }

    public String getJumpInfo() {
        return jumpInfo;
    }

    public void setJumpInfo(String jumpInfo) {
        this.jumpInfo = jumpInfo;
    }

    public JSONObject getJumpInfoJson() {
        if (this.jumpInfoJson == null) {
            this.jumpInfoJson = JSONObject.parseObject(this.jumpInfo);
        }
        return jumpInfoJson;
    }

    public void setJumpInfoJson(JSONObject jumpInfoJson) {
        this.jumpInfoJson = jumpInfoJson;
    }
}
